/*!
 * @eslint-sets/eslint-config-react v5.14.0
 * Eslint config sets for react
 * (c) 2021-2024 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
'use strict';

var localPkg = require('local-pkg');

const tsExits = localPkg.isPackageExists("typescript");
if (!tsExits)
  console.warn("[@eslint-sets/eslint-config] TypeScript is not installed, fallback to JS only.");
const config = {
  plugins: [
    "react",
    "react-hooks",
    "prettier"
    // 'eslint-plugin-tsdoc'
  ],
  extends: [
    "plugin:react/recommended",
    tsExits ? "@eslint-sets/eslint-config-ts" : "@eslint-sets/eslint-config-basic",
    "plugin:vitest-globals/recommended",
    "prettier"
  ],
  rules: {
    "jsx-quotes": ["error", "prefer-double"],
    "react/react-in-jsx-scope": "off"
  },
  globals: {
    __DEV__: false,
    h: true,
    window: true,
    define: true,
    history: true,
    location: true,
    $: true,
    process: true
  },
  overrides: [
    {
      files: ["**/__tests__/*.{j,t}s?(x)", "**/*.spec.{j,t}s?(x)"],
      env: {
        mocha: true,
        jest: true
      },
      rules: {
        "no-console": "off"
      }
    }
  ],
  settings: {
    react: {
      version: "17.0.0"
    }
  }
};

module.exports = config;
